Contributing
------------

Welcome!

Install
^^^^^^^

The package can be installed with the following command run from the root of the package.

.. code:: bash

    pip install  -e .[dev,test,doc]

Pre-commit hook
^^^^^^^^^^^^^^^

A pre-commit hook that runs `flake8` can be installed by running

.. code:: bash

    pre-commit install


